@@ -326,7 +326,7 @@ class KustoConnectionStringBuilder:
     def with_aad_managed_service_identity_authentication(
         cls, connection_string: str, client_id: str = None, object_id: str = None, msi_res_id: str = None, timeout: int = None
     ) -> "KustoConnectionStringBuilder":
-        """"
+        """
         Creates a KustoConnection string builder that will authenticate with AAD application, using
         an application token obtained from a Microsoft Service Identity endpoint. An optional user
         assigned application ID can be added to the token.
@@ -700,9 +700,21 @@ class KustoClient:
                 return KustoResponseDataSetV2(response.json())
             return KustoResponseDataSetV1(response.json())
 
+        if response.status_code == 404:
+            if payload:
+                raise KustoServiceError("The ingestion endpoint does not exist. Please enable streaming ingestion on your cluster.", response)
+            else:
+                raise KustoServiceError("The requested endpoint '{}' does not exist.".format(endpoint), response)
+
         if payload:
             raise KustoServiceError(
-                "An error occurred while trying to ingest: Status: {0.status_code}, Reason: {0.reason}, Text: {0.text}".format(response), response
+                "An error occurred while trying to ingest: Status: {0.status_code}, Reason: {0.reason}, Text: {0.text}.".format(response), response
             )
 
-        raise KustoServiceError([response.json()], response)
+        try:
+            raise KustoServiceError([response.json()], response)
+        except ValueError:
+            if response.text:
+                raise KustoServiceError([response.text], response)
+            else:
+                raise KustoServiceError("Server error response contains no data.", response)
