@@ -3,6 +3,7 @@
 import datetime
 import io
 import os
+import random
 import sys
 import time
 import uuid
@@ -24,13 +25,12 @@ from azure.kusto.ingest import (
     FileDescriptor,
 )
 
+CLEAR_DB_CACHE = ".clear database cache streamingingestion schema"
+
 
 class TestData:
     """A class to define mappings to deft table."""
 
-    def __init__(self):
-        pass
-
     @staticmethod
     def test_table_csv_mappings():
         """A method to define csv mappings to test table."""
@@ -124,8 +124,8 @@ def dm_kcsb_from_env() -> KustoConnectionStringBuilder:
     return KustoConnectionStringBuilder.with_aad_application_key_authentication(dm_cs, app_id, app_key, auth_id)
 
 
-def clean_previous_tests(engine_client, database, table):
-    engine_client.execute(database, ".drop table {0} ifexists".format(table))
+def teardown_module():
+    client.execute(test_db, ".drop table {} ifexists".format(test_table))
 
 
 def get_file_path() -> str:
@@ -142,14 +142,13 @@ def get_file_path() -> str:
 test_db = os.environ.get("TEST_DATABASE")
 
 python_version = "_".join([str(v) for v in sys.version_info[:3]])
-test_table = "python_test_{0}_{1}".format(python_version, str(int(time.time())))
+test_table = "python_test_{0}_{1}_{2}".format(python_version, str(int(time.time())), random.randint(1, 100000))
 client = KustoClient(engine_kcsb_from_env())
 ingest_client = KustoIngestClient(dm_kcsb_from_env())
 streaming_ingest_client = KustoStreamingIngestClient(engine_kcsb_from_env())
 
 start_time = datetime.datetime.now(datetime.timezone.utc)
 
-clean_previous_tests(client, test_db, test_table)
 input_folder_path = get_file_path()
 
 csv_file_path = os.path.join(input_folder_path, "dataset.csv")
@@ -288,7 +287,7 @@ def test_tsv_ingestion_csv_mapping():
 
 
 def test_streaming_ingest_from_opened_file():
-    client.execute(test_db, ".clear database cache streamingingestion schema")
+    client.execute(test_db, CLEAR_DB_CACHE)
     ingestion_properties = IngestionProperties(database=test_db, table=test_table, data_format=DataFormat.CSV)
 
     with open(csv_file_path, "r") as stream:
@@ -298,7 +297,7 @@ def test_streaming_ingest_from_opened_file():
 
 
 def test_streaming_ingest_from_csv_file():
-    client.execute(test_db, ".clear database cache streamingingestion schema")
+    client.execute(test_db, CLEAR_DB_CACHE)
     ingestion_properties = IngestionProperties(database=test_db, table=test_table, flush_immediately=True, data_format=DataFormat.CSV)
 
     for f in [csv_file_path, zipped_csv_file_path]:
@@ -308,7 +307,7 @@ def test_streaming_ingest_from_csv_file():
 
 
 def test_streaming_ingest_from_json_file():
-    client.execute(test_db, ".clear database cache streamingingestion schema")
+    client.execute(test_db, CLEAR_DB_CACHE)
     ingestion_properties = IngestionProperties(
         database=test_db,
         table=test_table,
@@ -325,7 +324,7 @@ def test_streaming_ingest_from_json_file():
 
 
 def test_streaming_ingest_from_csv_io_streams():
-    client.execute(test_db, ".clear database cache streamingingestion schema")
+    client.execute(test_db, CLEAR_DB_CACHE)
     ingestion_properties = IngestionProperties(database=test_db, table=test_table, data_format=DataFormat.CSV)
     byte_sequence = b'0,00000000-0000-0000-0001-020304050607,0,0,0,0,0,0,0,0,0,0,2014-01-01T01:01:01.0000000Z,Zero,"Zero",0,00:00:00,,null'
     bytes_stream = io.BytesIO(byte_sequence)
@@ -389,7 +388,3 @@ def test_streaming_ingest_from_dataframe():
     ingest_client.ingest_from_dataframe(df, ingestion_properties)
 
     assert_rows_added(1, timeout=120)
-
-
-def pytest_sessionfinish(session, exitstatus):
-    client.execute(test_db, ".drop table {} ifexists".format(test_table))
