@@ -11,6 +11,9 @@ from azure.kusto.ingest._resource_manager import _ResourceUri
 from azure.kusto.ingest.status import KustoIngestStatusQueues, SuccessMessage, FailureMessage
 from azure.storage.queue import QueueMessage, QueueClient
 
+ENDPOINT_SUFFIX = "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
+OBJECT_TYPE = "core.windows.net"
+
 
 def mock_message(success):
     m = QueueMessage()
@@ -92,15 +95,17 @@ class StatusQTests(unittest.TestCase):
         ) as mocked_get_failed_qs, mock.patch.object(QueueClient, "peek_messages", autospec=True, side_effect=fake_peek) as q_mock:
             fake_failed_queue = _ResourceUri(
                 "mocked_storage_account1",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qf_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
             fake_success_queue = _ResourceUri(
                 "mocked_storage_account2",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qs_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
 
             mocked_get_success_qs.return_value = [fake_success_queue]
@@ -130,21 +135,24 @@ class StatusQTests(unittest.TestCase):
 
             fake_failed_queue1 = _ResourceUri(
                 "mocked_storage_account_f1",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qf_1_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
             fake_failed_queue2 = _ResourceUri(
                 "mocked_storage_account_f2",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qf_2_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
             fake_success_queue = _ResourceUri(
                 "mocked_storage_account2",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qs_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
 
             mocked_get_success_qs.return_value = [fake_success_queue]
@@ -188,28 +196,34 @@ class StatusQTests(unittest.TestCase):
         with mock.patch.object(client._resource_manager, "get_successful_ingestions_queues") as mocked_get_success_qs, mock.patch.object(
             client._resource_manager, "get_failed_ingestions_queues"
         ) as mocked_get_failed_qs, mock.patch.object(
-            QueueClient, "receive_messages", autospec=True, side_effect=fake_receive,
+            QueueClient,
+            "receive_messages",
+            autospec=True,
+            side_effect=fake_receive,
         ) as q_receive_mock, mock.patch.object(
             QueueClient, "delete_message", return_value=None
         ) as q_del_mock:
 
             fake_failed_queue1 = _ResourceUri(
                 "mocked_storage_account_f1",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qf_1_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
             fake_failed_queue2 = _ResourceUri(
                 "mocked_storage_account_f2",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qf_2_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
             fake_success_queue = _ResourceUri(
                 "mocked_storage_account2",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qs_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
 
             mocked_get_success_qs.return_value = [fake_success_queue]
@@ -251,22 +265,27 @@ class StatusQTests(unittest.TestCase):
         with mock.patch.object(client._resource_manager, "get_successful_ingestions_queues"), mock.patch.object(
             client._resource_manager, "get_failed_ingestions_queues"
         ) as mocked_get_failed_qs, mock.patch.object(
-            QueueClient, "receive_messages", autospec=True, side_effect=fake_receive,
+            QueueClient,
+            "receive_messages",
+            autospec=True,
+            side_effect=fake_receive,
         ) as q_receive_mock, mock.patch.object(
             QueueClient, "delete_message", return_value=None
         ):
 
             fake_failed_queue1 = _ResourceUri(
                 "mocked_storage_account_f1",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qf_1_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
             fake_failed_queue2 = _ResourceUri(
                 "mocked_storage_account_f2",
+                OBJECT_TYPE,
                 "queue",
                 "mocked_qf_2_name",
-                "sp=rl&st=2020-05-20T13:38:37Z&se=2020-05-21T13:38:37Z&sv=2019-10-10&sr=c&sig=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                ENDPOINT_SUFFIX,
             )
 
             mocked_get_failed_qs.return_value = [fake_failed_queue1, fake_failed_queue2]
